docx\_parser\_converter.docx\_parsers.utils module
==================================================

.. automodule:: docx_parser_converter.docx_parsers.utils
   :members:
   :undoc-members:
   :show-inheritance:
